package com.samelement.iot_notification.util;


import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;

import com.samelement.iot_notification.R;

public class AnalyticIconHelper {

    public static Bitmap getLargeIconBitmap(Resources res, String analyticModel) {
        /*
        Simple Time Series
        Time Series With Bar
        Horizontal Bar
        Rounded Bar
        Candlestick
        Percentage Gauge
        Button
        Switch
        Slider
        LED
        Bell
        Power-button
        * */
        switch (analyticModel.toLowerCase()) {
            case "simple time series":
            case "simple-time-series":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_time_series, 100, 100);
            case "time series with bar":
            case "bar-time-series":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_time_series_with_bar, 100, 100);
            case "horizontal bar":
            case "horizontal-bar":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_horizontal_bar, 100, 100);
            case "rounded bar":
            case "rounded-bar":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_rounded_bar, 100, 100);
            case "candlestick":
            case "candle-stick":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_candlestick, 100, 100);
            case "percentage gauge":
            case "gauge":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_gauge, 100, 100);
            case "button":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_button, 100, 100);
            case "switch":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_switch, 100, 100);
            case "slider":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_slider, 100, 100);
            case "led":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_led, 100, 100);
            case "bell":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_bell, 100, 100);
            case "power-button":
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_power_button, 100, 100);
            default:
                return decodeSampledBitmapFromResource(res, R.mipmap.ic_launcher, 100, 100);
        }
    }

    public static Bitmap decodeSampledBitmapFromResource(Resources res, int resId,
                                                         int reqWidth, int reqHeight) {

        // First decode with inJustDecodeBounds=true to check dimensions
        final BitmapFactory.Options options = new BitmapFactory.Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeResource(res, resId, options);

        // Calculate inSampleSize
        options.inSampleSize = calculateInSampleSize(options, reqWidth, reqHeight);

        // Decode bitmap with inSampleSize set
        options.inJustDecodeBounds = false;
        return BitmapFactory.decodeResource(res, resId, options);
    }

    private static int calculateInSampleSize(
            BitmapFactory.Options options, int reqWidth, int reqHeight) {
        // Raw height and width of image
        final int height = options.outHeight;
        final int width = options.outWidth;
        int inSampleSize = 1;

        if (height > reqHeight || width > reqWidth) {

            final int halfHeight = height / 2;
            final int halfWidth = width / 2;

            // Calculate the largest inSampleSize value that is a power of 2 and keeps both
            // height and width larger than the requested height and width.
            while ((halfHeight / inSampleSize) >= reqHeight
                    && (halfWidth / inSampleSize) >= reqWidth) {
                inSampleSize *= 2;
            }
        }

        return inSampleSize;
    }
}
