package com.samelement.iot_notification.util;

import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;

import com.samelement.iot_notification.R;

public class StateIndicatorHelper {

    public static String getStateName(String state) {
        switch (state) {
            case "init":
                return "Initializing";
            case "ready":
                return "Connected";
            case "disconnected":
                return "Disconnected";
            case "sleeping":
                return "Sleep";
            case "lost":
                return "Lost";
            case "alert":
                return "Alert";
        }

        return "Lost";
    }

    public static Bitmap getStateImage(Resources res, String state) {
        switch (state) {
            case "init":
                return decodeSampledBitmapFromResource(res, R.drawable.install, 100, 100);
            case "ready":
                return decodeSampledBitmapFromResource(res, R.drawable.usb_cable, 100, 100);
            case "disconnected":
                return decodeSampledBitmapFromResource(res, R.drawable.disconnected, 100, 100);
            case "sleeping":
                return decodeSampledBitmapFromResource(res, R.drawable.dreaming, 100, 100);
            case "lost":
                return decodeSampledBitmapFromResource(res, R.drawable.signal, 100, 100);
            case "alert":
                return decodeSampledBitmapFromResource(res, R.drawable.warning, 100, 100);
        }

        return decodeSampledBitmapFromResource(res, R.drawable.warning, 100, 100);
    }

    public static Bitmap decodeSampledBitmapFromResource(Resources res, int resId,
                                                          int reqWidth, int reqHeight) {

        // First decode with inJustDecodeBounds=true to check dimensions
        final BitmapFactory.Options options = new BitmapFactory.Options();
        options.inJustDecodeBounds = true;
        BitmapFactory.decodeResource(res, resId, options);

        // Calculate inSampleSize
        options.inSampleSize = calculateInSampleSize(options, reqWidth, reqHeight);

        // Decode bitmap with inSampleSize set
        options.inJustDecodeBounds = false;
        return BitmapFactory.decodeResource(res, resId, options);
    }

    private static int calculateInSampleSize(
            BitmapFactory.Options options, int reqWidth, int reqHeight) {
        // Raw height and width of image
        final int height = options.outHeight;
        final int width = options.outWidth;
        int inSampleSize = 1;

        if (height > reqHeight || width > reqWidth) {

            final int halfHeight = height / 2;
            final int halfWidth = width / 2;

            // Calculate the largest inSampleSize value that is a power of 2 and keeps both
            // height and width larger than the requested height and width.
            while ((halfHeight / inSampleSize) >= reqHeight
                    && (halfWidth / inSampleSize) >= reqWidth) {
                inSampleSize *= 2;
            }
        }

        return inSampleSize;
    }
}
